#!/bin/sh

# http://mirrordirector.raspbian.org/raspbian/pool/main/s/squashfs-tools/
# ->  squashfs-tools_4.3-7_armhf.deb
#     -> mksquashfs
#     -> unsquashfs
#
# http://mirrordirector.raspbian.org/raspbian/pool/main/x/xz-utils/
# ->  liblzma5_5.2.2-1.3_armhf.deb
#     -> liblzma.so.5
#
# http://mirrordirector.raspbian.org/raspbian/pool/main/l/lz4/
# ->  liblz4-1_1.8.2-1+rpi1_armhf.deb
#     -> liblz4.so.1
#
# http://mirrordirector.raspbian.org/raspbian/pool/main/l/lzo2/
# ->  liblzo2-2_2.10-0.1_armhf.deb
#     -> liblzo2.so.2
#
# sh < ./libreelec-ffmpeg-patch.sh

exit_on_error() {
  echo "Error: ${@}"
  exit 1
}

MY_PATH=`pwd`
export PATH=${PATH}:${MY_PATH}/bin
export LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MY_PATH}/lib
if [ -f    ${MY_PATH}/bin/unsquashfs ] ; then
  chmod +x ${MY_PATH}/bin/unsquashfs
fi
if [ -f    ${MY_PATH}/bin/mksquashfs ] ; then
  chmod +x ${MY_PATH}/bin/mksquashfs
fi

#FFMPEG=/usr/bin/ffmpeg
#if [ -f          ${FFMPEG} ] ; then
#  exit_on_error "${FFMPEG} exists. Nothing to do."
#fi

FFMPEG=/storage/.kodi/addons/tools.ffmpeg-tools/bin/ffmpeg
if [ ! -f      ${FFMPEG} ] ; then
  exit_on_error "ffmpeg/ffmpeg-tools addon is missing."
fi

UPD_DIR=/storage/.update/
if [ ! -d        ${UPD_DIR} ] ; then
  exit_on_error "${UPD_DIR} does not exist."
fi

UPD_NUM=`find  ${UPD_DIR} | wc -l`
if [ ${UPD_NUM} = 1 ] ; then
  exit_on_error "${UPD_DIR} is empty."
fi

if [ ! ${UPD_NUM} = 2 ] ; then
  exit_on_error "too many directories/files in ${UPD_DIR}."
fi

UPD_TAR=`find ${UPD_DIR} | grep -c "\.tar"`
if [ ! ${UPD_TAR} = 1 ] ; then
  exit_on_error "no tar file in ${UPD_DIR}."
fi
UPD_TAR=`find ${UPD_DIR} | grep    "\.tar"`

cd   ${UPD_DIR} || exit_on_error "can't cd to ${UPD_DIR}."
echo "###  Extracting ${UPD_TAR} ...  ###"
tar -xf ${UPD_TAR}
rm  -f  ${UPD_TAR}

UPD_NUM=`find  ${UPD_DIR} -maxdepth 1 | wc -l`
if [ ${UPD_NUM} = 1 ] ; then
  exit_on_error "${UPD_DIR} is empty."
fi

if [ ! ${UPD_NUM} = 2 ] ; then
  exit_on_error "too many directories/files in ${UPD_DIR}."
fi

cd *
UPD_SUB_DIR=`pwd`
TARGET_DIR=${UPD_SUB_DIR}/target/

echo "###  Unsquashing SYSTEM ...  ###"
cd ${TARGET_DIR}           || exit_on_error "${TARGET_DIR} does not exist."
unsquashfs          SYSTEM || exit_on_error "unsquashfs failed."
rm         -f       SYSTEM
UPD_BIN_DIR=${TARGET_DIR}/squashfs-root/usr/bin/

echo "###  Patching SYSTEM ...  ###"
cd ${UPD_BIN_DIR} || exit_on_error "${UPD_BIN_DIR} does not exist."
ln -s ${FFMPEG} . || exit_on_error "linking ${FFMPEG} failed."

echo "###  Creating squashfs SYSTEM ...  ###"
cd ${TARGET_DIR}
mksquashfs squashfs-root SYSTEM -comp lz4 || exit_on_error "mksquashfs failed."
rm -r      squashfs-root/
cd ${UPD_SUB_DIR}
md5sum target/SYSTEM > target/SYSTEM.md5  || exit_on_error "md5sum failed."

echo "###  Creating update TAR file ...  ###"
cd      ${UPD_DIR}
tar -cf ${UPD_TAR} *              || exit_on_error "creating ${UPD_TAR} failed."
rm  -rf            ${UPD_SUB_DIR}

echo "Reboot your system to update."
